@@ -1,5 +1,5 @@
 /* `time' utility to display resource usage of processes, main source file.
-   Copyright (C) 1990, 91, 92, 93, 96 Free Software Foundation, Inc.
+   Copyright (C) 1990-2018 Free Software Foundation, Inc.
 
    Originally written by David Keppel <pardo@cs.washington.edu>.
    Heavily modified by David MacKenzie <djm@gnu.ai.mit.edu>.
@@ -33,6 +33,7 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <stdbool.h>
+#include <stdnoreturn.h>
 #include <string.h>
 #include <limits.h>
 #include <unistd.h>
@@ -214,7 +215,7 @@ static struct option longopts[] =
 # define PROGRAM_NAME "time"
 
 
-static void
+noreturn static void
 usage (int status)
 {
   if (status != EXIT_SUCCESS)
@@ -249,7 +250,7 @@ Usage: %s [-apvV] [-f format] [-o file] [--append] [--verbose]\n\
   -f, --format=FORMAT       use the specified FORMAT instead of the default\n\
 "), stdout);
   fputs (_("\
-  -o, --output=FILE         write to FILE instead of STDOUT\n"), stdout);
+  -o, --output=FILE         write to FILE instead of STDERR\n"), stdout);
   fputs (_("\
   -p, --portability         print POSIX standard 1003.2 conformant string:\n\
                               real %%e\n\
@@ -428,8 +429,10 @@ summarize (fp, fmt, command, resp)
 {
   unsigned long r;		/* Elapsed real milliseconds.  */
   unsigned long v;		/* Elapsed virtual (CPU) milliseconds.  */
+  unsigned long us_r;		/* Elapsed real microseconds.  */
+  unsigned long us_v;		/* Elapsed virtual (CPU) microseconds.  */
 
-  if (!quiet)
+  if (!quiet && output_format != posix_format)
     {
       if (WIFSTOPPED (resp->waitstatus))
         fprintf (fp, "Command stopped by signal %d\n",
@@ -452,6 +455,9 @@ summarize (fp, fmt, command, resp)
   v = resp->ru.ru_utime.tv_sec * 1000 + resp->ru.ru_utime.TV_MSEC +
     resp->ru.ru_stime.tv_sec * 1000 + resp->ru.ru_stime.TV_MSEC;
 
+  us_r = resp->elapsed.tv_usec;
+  us_v = resp->ru.ru_utime.tv_usec + resp->ru.ru_stime.tv_usec;
+
   while (*fmt)
     {
       switch (*fmt)
@@ -509,6 +515,8 @@ summarize (fp, fmt, command, resp)
 	      /* % cpu is (total cpu time)/(elapsed time).  */
 	      if (r > 0)
 		fprintf (fp, "%lu%%", (v * 100 / r));
+	      else if (us_r > 0)
+		fprintf (fp, "%lu%%", (us_v * 100 / us_r));
 	      else
 		fprintf (fp, "?%%");
 	      break;
